pub struct TimerKey(/* private fields */);Trait Implementations
Sourceimpl Key for TimerKey
impl Key for TimerKey
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for TimerKey
impl Ord for TimerKey
Sourceimpl PartialOrd for TimerKey
impl PartialOrd for TimerKey
impl Copy for TimerKey
impl Eq for TimerKey
impl StructuralPartialEq for TimerKey